@@ -3,8 +3,7 @@
  * for tbl_relation.php
  *
  */
-function show_hide_clauses($thisDropdown)
-{
+function show_hide_clauses ($thisDropdown) {
     if ($thisDropdown.val() === '') {
         $thisDropdown.parent().nextAll('span').hide();
     } else {
@@ -17,13 +16,13 @@ function show_hide_clauses($thisDropdown)
 /**
  * Sets dropdown options to values
  */
-function setDropdownValues($dropdown, values, selectedValue) {
+function setDropdownValues ($dropdown, values, selectedValue) {
     $dropdown.empty();
     var optionsAsString = '';
     // add an empty string to the beginning for empty selection
     values.unshift('');
     $.each(values, function () {
-        optionsAsString += "<option value='" + this + "'" + (selectedValue == this ? " selected='selected'" : "") + ">" + this + "</option>";
+        optionsAsString += '<option value=\'' + escapeHtml(this) + '\'' + (selectedValue === escapeHtml(this) ? ' selected=\'selected\'' : '') + '>' + escapeHtml(this) + '</option>';
     });
     $dropdown.append($(optionsAsString));
 }
@@ -33,20 +32,23 @@ function setDropdownValues($dropdown, values, selectedValue) {
  *
  * @param $dropdown the dropdown whose value got changed
  */
-function getDropdownValues($dropdown) {
-    var foreignDb = null, foreignTable = null;
-    var $tableDd, $columnDd;
+function getDropdownValues ($dropdown) {
+    var foreignDb = null;
+    var foreignTable = null;
+    var $databaseDd;
+    var $tableDd;
+    var $columnDd;
     var foreign = '';
     // if the changed dropdown is for foreign key constraints
     if ($dropdown.is('select[name^="destination_foreign"]')) {
         $databaseDd = $dropdown.parent().parent().parent().find('select[name^="destination_foreign_db"]');
-        $tableDd  = $dropdown.parent().parent().parent().find('select[name^="destination_foreign_table"]');
-        $columnDd = $dropdown.parent().parent().parent().find('select[name^="destination_foreign_column"]');
+        $tableDd    = $dropdown.parent().parent().parent().find('select[name^="destination_foreign_table"]');
+        $columnDd   = $dropdown.parent().parent().parent().find('select[name^="destination_foreign_column"]');
         foreign = '_foreign';
     } else { // internal relations
         $databaseDd = $dropdown.parent().find('select[name^="destination_db"]');
-        $tableDd  = $dropdown.parent().find('select[name^="destination_table"]');
-        $columnDd = $dropdown.parent().find('select[name^="destination_column"]');
+        $tableDd    = $dropdown.parent().find('select[name^="destination_table"]');
+        $columnDd   = $dropdown.parent().find('select[name^="destination_column"]');
     }
 
     // if the changed dropdown is a database selector
@@ -61,7 +63,7 @@ function getDropdownValues($dropdown) {
     } else { // if a table selector
         foreignDb = $databaseDd.val();
         foreignTable = $dropdown.val();
-         // if no table is selected empty the column dropdown
+        // if no table is selected empty the column dropdown
         if (foreignTable === '') {
             setDropdownValues($columnDd, []);
             return;
@@ -69,22 +71,24 @@ function getDropdownValues($dropdown) {
     }
     var $msgbox = PMA_ajaxShowMessage();
     var $form = $dropdown.parents('form');
-    var url = 'tbl_relation.php?getDropdownValues=true&ajax_request=true' +
-        '&token=' + $form.find('input[name="token"]').val() +
-        '&db=' + $form.find('input[name="db"]').val() +
-        '&table=' + $form.find('input[name="table"]').val() +
-        '&foreign=' + (foreign !== '') +
-        '&foreignDb=' + encodeURIComponent(foreignDb) +
+    var argsep = PMA_commonParams.get('arg_separator');
+    var params = 'getDropdownValues=true' + argsep + 'ajax_request=true' +
+        argsep + 'db=' + $form.find('input[name="db"]').val() +
+        argsep + 'table=' + $form.find('input[name="table"]').val() +
+        argsep + 'foreign=' + (foreign !== '') +
+        argsep + 'foreignDb=' + encodeURIComponent(foreignDb) +
         (foreignTable !== null ?
-            '&foreignTable=' + encodeURIComponent(foreignTable) : ''
+            argsep + 'foreignTable=' + encodeURIComponent(foreignTable) : ''
         );
     var $server = $form.find('input[name="server"]');
     if ($server.length > 0) {
-        url += '&server=' + $form.find('input[name="server"]').val();
+        params += argsep + 'server=' + $form.find('input[name="server"]').val();
     }
     $.ajax({
-        url: url,
-        datatype: 'json',
+        type: 'POST',
+        url: 'tbl_relation.php',
+        data: params,
+        dataType: 'json',
         success: function (data) {
             PMA_ajaxRemoveMessage($msgbox);
             if (typeof data !== 'undefined' && data.success) {
@@ -101,7 +105,8 @@ function getDropdownValues($dropdown) {
                     ) {
                         primary = data.primary[0];
                     }
-                    setDropdownValues($columnDd, data.columns, primary);
+                    setDropdownValues($columnDd.first(), data.columns, primary);
+                    setDropdownValues($columnDd.slice(1), data.columns);
                 }
             } else {
                 PMA_ajaxShowMessage(data.error, false);
@@ -126,7 +131,6 @@ AJAX.registerTeardown('tbl_relation.js', function () {
 });
 
 AJAX.registerOnload('tbl_relation.js', function () {
-
     /**
      * Ajax event handler to fetch table/column dropdown values.
      */
@@ -149,20 +153,20 @@ AJAX.registerOnload('tbl_relation.js', function () {
 
         // Add field.
         $(this)
-        .prev('span')
-        .clone(true, true)
-        .insertBefore($(this))
-        .find('select')
-        .val('');
+            .prev('span')
+            .clone(true, true)
+            .insertBefore($(this))
+            .find('select')
+            .val('');
 
         // Add foreign field.
         var $source_elem = $('select[name^="destination_foreign_column[' +
             $(this).attr('data-index') + ']"]:last').parent();
         $source_elem
-        .clone(true, true)
-        .insertAfter($source_elem)
-        .find('select')
-        .val('');
+            .clone(true, true)
+            .insertAfter($source_elem)
+            .find('select')
+            .val('');
     });
 
     /**
@@ -173,30 +177,31 @@ AJAX.registerOnload('tbl_relation.js', function () {
         event.stopPropagation();
 
         var $prev_row = $(this).closest('tr').prev('tr');
-        var odd_even = ($prev_row.attr('class') == 'odd') ? 'even' : 'odd';
-        var $new_row = $prev_row.clone(true, true).attr('class', odd_even);
+        var $newRow = $prev_row.clone(true, true);
 
         // Update serial number.
-        var curr_index = $new_row
+        var curr_index = $newRow
             .find('a.add_foreign_key_field')
             .attr('data-index');
         var new_index = parseInt(curr_index) + 1;
-        $new_row.find('a.add_foreign_key_field').attr('data-index', new_index);
+        $newRow.find('a.add_foreign_key_field').attr('data-index', new_index);
 
         // Update form parameter names.
-        $new_row.find('select[name^="foreign_key_fields_name"]:not(:first), ' +
+        $newRow.find('select[name^="foreign_key_fields_name"]:not(:first), ' +
             'select[name^="destination_foreign_column"]:not(:first)'
         ).each(function () {
             $(this).parent().remove();
         });
-        $new_row.find('input, select').each(function () {
+        $newRow.find('input, select').each(function () {
             $(this).attr('name',
                 $(this).attr('name').replace(/\d/, new_index)
             );
         });
-
+        $newRow.find('input[type="text"]').each(function () {
+            $(this).val('');
+        });
         // Finally add the row.
-        $new_row.insertAfter($prev_row);
+        $newRow.insertAfter($prev_row);
     });
 
     /**
@@ -219,16 +224,20 @@ AJAX.registerOnload('tbl_relation.js', function () {
 
         $anchor.PMA_confirm(question, $anchor.attr('href'), function (url) {
             var $msg = PMA_ajaxShowMessage(PMA_messages.strDroppingForeignKey, false);
-            $.get(url, {'is_js_confirmed': 1, 'ajax_request': true}, function (data) {
+            var params = getJSConfirmCommonParam(this, $anchor.getPostData());
+            $.post(url, params, function (data) {
                 if (data.success === true) {
                     PMA_ajaxRemoveMessage($msg);
                     PMA_commonActions.refreshMain(false, function () {
                         // Do nothing
                     });
                 } else {
-                    PMA_ajaxShowMessage(PMA_messages.strErrorProcessingRequest + " : " + data.error, false);
+                    PMA_ajaxShowMessage(PMA_messages.strErrorProcessingRequest + ' : ' + data.error, false);
                 }
-            }); // end $.get()
+            }); // end $.post()
         }); // end $.PMA_confirm()
-    }); //end Drop Foreign key
+    }); // end Drop Foreign key
+
+    var windowwidth = $(window).width();
+    $('.jsresponsive').css('max-width', (windowwidth - 35) + 'px');
 });
