@@ -4,12 +4,12 @@
  *
  * @package PhpMyAdmin
  */
-AJAX.registerOnload('transformations/xml_editor.js', function() {
-    $.each($('textarea.transform_xml_editor'), function (i, e) {
-        CodeMirror.fromTextArea(e, {
+AJAX.registerOnload('transformations/xml_editor.js', function () {
+    $('textarea.transform_xml_editor').each(function () {
+        CodeMirror.fromTextArea(this, {
             lineNumbers: true,
             indentUnit: 4,
-            mode: "application/xml",
+            mode: 'application/xml',
             lineWrapping: true
         });
     });
