@@ -6,22 +6,28 @@
  * @package PhpMyAdmin
  */
 
+use PhpMyAdmin\Core;
+use PhpMyAdmin\Mime;
+use PhpMyAdmin\Response;
+
 /**
  * Common functions.
  */
-// we don't want the usual PMA_Response-generated HTML above the column's data
-define('PMA_BYPASS_GET_INSTANCE', 1);
 require_once 'libraries/common.inc.php';
-require_once 'libraries/mime.lib.php';
+
+// we don't want the usual PhpMyAdmin\Response-generated HTML above the column's
+// data
+$response = Response::getInstance();
+$response->disable();
 
 /* Check parameters */
-PMA_Util::checkParameters(
+PhpMyAdmin\Util::checkParameters(
     array('db', 'table')
 );
 
 /* Select database */
 if (!$GLOBALS['dbi']->selectDb($db)) {
-    PMA_Util::mysqlDie(
+    PhpMyAdmin\Util::mysqlDie(
         sprintf(__('\'%s\' database does not exist.'), htmlspecialchars($db)),
         '', false
     );
@@ -29,28 +35,28 @@ if (!$GLOBALS['dbi']->selectDb($db)) {
 
 /* Check if table exists */
 if (!$GLOBALS['dbi']->getColumns($db, $table)) {
-    PMA_Util::mysqlDie(__('Invalid table name'));
+    PhpMyAdmin\Util::mysqlDie(__('Invalid table name'));
 }
 
 /* Grab data */
-$sql = 'SELECT ' . PMA_Util::backquote($_GET['transform_key'])
-    . ' FROM ' . PMA_Util::backquote($table)
+$sql = 'SELECT ' . PhpMyAdmin\Util::backquote($_GET['transform_key'])
+    . ' FROM ' . PhpMyAdmin\Util::backquote($table)
     . ' WHERE ' . $_GET['where_clause'] . ';';
 $result = $GLOBALS['dbi']->fetchValue($sql);
 
 /* Check return code */
 if ($result === false) {
-    PMA_Util::mysqlDie(
+    PhpMyAdmin\Util::mysqlDie(
         __('MySQL returned an empty result set (i.e. zero rows).'), $sql
     );
 }
 
 /* Avoid corrupting data */
-@ini_set('url_rewriter.tags', '');
+ini_set('url_rewriter.tags', '');
 
-PMA_downloadHeader(
+Core::downloadHeader(
     $table . '-' .  $_GET['transform_key'] . '.bin',
-    PMA_detectMIME($result),
-    /*overload*/mb_strlen($result, '8bit')
+    Mime::detect($result),
+    strlen($result)
 );
 echo $result;
